package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.entity.DragTableCondition;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.DragTableConditionMapper;
import com.ruoyi.system.service.IDragTableConditionService;

/**
 * 动态格条件Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-07-31
 */
@Service
public class DragTableConditionServiceImpl implements IDragTableConditionService 
{
    @Autowired
    private DragTableConditionMapper dragTableConditionMapper;

    /**
     * 查询动态格条件
     * 
     * @param tcId 动态格条件主键
     * @return 动态格条件
     */
    @Override
    public DragTableCondition selectDragTableConditionByTcId(Long tcId)
    {
        return dragTableConditionMapper.selectDragTableConditionByTcId(tcId);
    }

    /**
     * 查询动态格条件列表
     * 
     * @param dragTableCondition 动态格条件
     * @return 动态格条件
     */
    @Override
    public List<DragTableCondition> selectDragTableConditionList(DragTableCondition dragTableCondition)
    {
        return dragTableConditionMapper.selectDragTableConditionList(dragTableCondition);
    }

    /**
     * 新增动态格条件
     * 
     * @param dragTableCondition 动态格条件
     * @return 结果
     */
    @Override
    public int insertDragTableCondition(DragTableCondition dragTableCondition)
    {
        dragTableCondition.setCreateTime(DateUtils.getNowDate());
        return dragTableConditionMapper.insertDragTableCondition(dragTableCondition);
    }

    /**
     * 修改动态格条件
     * 
     * @param dragTableCondition 动态格条件
     * @return 结果
     */
    @Override
    public int updateDragTableCondition(DragTableCondition dragTableCondition)
    {
        dragTableCondition.setUpdateTime(DateUtils.getNowDate());
        return dragTableConditionMapper.updateDragTableCondition(dragTableCondition);
    }

    /**
     * 批量删除动态格条件
     * 
     * @param tcIds 需要删除的动态格条件主键
     * @return 结果
     */
    @Override
    public int deleteDragTableConditionByTcIds(Long[] tcIds)
    {
        return dragTableConditionMapper.deleteDragTableConditionByTcIds(tcIds);
    }

    /**
     * 删除动态格条件信息
     * 
     * @param tcId 动态格条件主键
     * @return 结果
     */
    @Override
    public int deleteDragTableConditionByTcId(Long tcId)
    {
        return dragTableConditionMapper.deleteDragTableConditionByTcId(tcId);
    }
}
